==> MediaWikiLanguageExtensionBundle-2020.04.tar.bz2: extensions/Translate/tests/phpunit/unit/MessageValidator/Validators/SmartFormatPluralValidatorTest.php <==
<?php
/**
 * @file
 * @license GPL-2.0-or-later
 */

use MediaWiki\Extensions\Translate\MessageValidator\Validators\SmartFormatPluralValidator;

/**
 * @covers \MediaWiki\Extensions\Translate\MessageValidator\Validators\SmartFormatPluralValidator
 */
class SmartFormatPluralValidatorTest extends MediaWikiUnitTestCase {
	public static function provideValidate() {
		$key = 'k';
		$code = 'en';
		$message = new FatMessage( $key, '{0:message|messages}' );
		$message->setTranslation( '{1:test|tests}{0:message|messages}' );
		yield [
			$message,
			$code,
			[ 'plural', 'unsupported', $key, $code ]
		];

		$code = 'en';
		$message = new FatMessage( $key, '{0:message|messages}' );
		$message->setTranslation( 'translation' );
		yield [
			$message,
			$code,
			[ 'plural', 'missing', $key, $code ]
		];

		$code = 'en';
		$message = new FatMessage( $key, '{0:message|messages}' );
		$message->setTranslation( '{0:message|messages|messages}' );
		yield [
			$message,
			$code,
			[ 'plural', 'forms', $key, $code ]
		];

		$code = 'en';
		$message = new FatMessage( $key, '{0:message|messages}' );
		$message->setTranslation( '{0:message|messages}' );
		yield [
			$message,
			$code,
			null
		];
	}

	/**
	 * @dataProvider provideValidate
	 */
	public function testValidate( TMessage $message, $code, $expected ) {
		$validator = new SmartFormatPluralValidator();

		$notices = [];
		$validator->validate( $message, $code, $notices );

		if ( $expected === null ) {
			$this->assertSame( [], $notices );
		} else {
			$this->assertSame( $expected, $notices[ $message->key() ][ 0 ][ 0 ] );
		}
	}

	public static function provideInsertable() {
		yield [
			'{0:message|messages}',
			'{0:|}',
			'{0:',
			'|}'
		];

		yield [
			'contains no pluralization',
			null
		];
	}

	/**
	 * @dataProvider provideInsertable
	 */
	public function testInsertable( $text, $displayText, $preText = '', $postText = '' ) {
		$validator = new SmartFormatPluralValidator();

		$insertables = $validator->getInsertables( $text );

		if ( $displayText === null ) {
			$this->assertSame( [], $insertables );
		} else {
			$this->assertCount( 1, $insertables );
			$this->assertSame( $insertables[0]->getPreText(), $preText );
			$this->assertSame( $insertables[0]->getPostText(), $postText );
			$this->assertSame( $insertables[0]->getDisplayText(), $displayText );
		}
	}
}

==> MediaWikiLanguageExtensionBundle-2020.07.tar.bz2: extensions/Translate/tests/phpunit/unit/MessageValidator/Validators/SmartFormatPluralValidatorTest.php <==
<?php
declare( strict_types = 1 );

use MediaWiki\Extensions\Translate\MessageValidator\Validators\SmartFormatPluralValidator;

/**
 * @license GPL-2.0-or-later
 * @covers \MediaWiki\Extensions\Translate\MessageValidator\Validators\SmartFormatPluralValidator
 */
class SmartFormatPluralValidatorTest extends BaseValidatorTestCase {
	/** @dataProvider provideTestCases */
	public function test( ...$params ) {
		$this->runValidatorTests( new SmartFormatPluralValidator(), 'plural', ...$params );
	}

	public function provideTestCases() {
		yield [
			'{0:message|messages}',
			'{1:test|tests}{0:message|messages}',
			[ 'unsupported' ],
			'Using plural on an unsupported parameter is an issue'
		];

		yield [
			'{0:message|messages}',
			'translation',
			[ 'missing' ],
			'Missing plural on an unsupported parameter is an issue'
		];

		yield [
			'{0:message|messages}',
			'{0:message|messages|messages}',
			[ 'forms' ],
			'Extra plural form is an issue'
		];

		yield [
			'{0:message|messages}',
			'{0:message|messages}',
			[],
			'Correct plural forms are not an issue'
		];
	}

	/** @dataProvider provideInsertable */
	public function testInsertable( $text, $displayText, $preText = '', $postText = '' ) {
		$validator = new SmartFormatPluralValidator();

		$insertables = $validator->getInsertables( $text );

		if ( $displayText === null ) {
			$this->assertSame( [], $insertables );
		} else {
			$this->assertCount( 1, $insertables );
			$this->assertSame( $insertables[0]->getPreText(), $preText );
			$this->assertSame( $insertables[0]->getPostText(), $postText );
			$this->assertSame( $insertables[0]->getDisplayText(), $displayText );
		}
	}

	public static function provideInsertable() {
		yield [
			'{0:message|messages}',
			'{0:|}',
			'{0:',
			'|}'
		];

		yield [
			'contains no pluralization',
			null
		];
	}
}
